update

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MarkNotified

func MarkNotified(version string)

MarkNotified updates the cache to record that a notification was shown for the given version. Errors are silently ignored.

Types

type Result

type Result struct {
	CurrentVersion string
	NewVersion     string
}

Result holds the version information when an update is available.

func Check

func Check(ctx context.Context, client *github.Client, currentVersion string) *Result

Check queries for the latest release and returns a Result if a newer version is available and the notification has not been recently shown. Returns nil when no notification is needed or on any error (errors are silently ignored).

Jump to