Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Progress ¶
type Progress struct {
// contains filtered or unexported fields
}
Progress renders a single-line progress bar to the given writer. All methods are safe for concurrent use.
func New ¶
New creates a Progress that writes to w and starts a background ticker for spinner animation and terminal width refresh. fd is the file descriptor used to query terminal width.
Click to show internal directories.
Click to hide internal directories.