Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MarkNotified ¶
func MarkNotified(version string)
MarkNotified updates the cache to record that a notification was shown for the given version. Errors are silently ignored.
Types ¶
type Result ¶
Result holds the version information when an update is available.
Click to show internal directories.
Click to hide internal directories.